=========
harvester
=========

*********************************
An easy-to-use Web Scraping tool.
*********************************

Harvester is a library written in plain python. Its goal is to provide a no-dependencies library for easy web scrapping.

************
Installation
************

Installing from pip::

    pip install harvester

Installing from source::

    pip install git+https://github.com/blazaid/harvester

Requirements
============

No requirements for now, and if possible for never.

*************
Documentation
*************

We're in process of learning hoy to export the documentation to "readthedocs". Until then, the source code is a very
good place (and the only one) to get the documentation. We'll upload the documentation as soon as we can.


*******
Authors
*******

`harvester` was written by `Blazaid <alberto.da@gmail.com>`_ with help from `Davyria <https://github.com/davyria>`_.

Thanks
======

You.


Warning
=======

It has been developed with only python 3.X in mind, so it won't probably work on lower versions (i.e. not python 2.X
support).

Second warning
==============
English included both in this document and the code can be devastating for the brain of an average human being. Even so
we, the poor developers, are working hard to write as correctly as possible and learn along the way. The documentation
will be updated as we improve our language proficency as well as we receive critical / suggestions for this.
